@@ -54,7 +54,7 @@ class LocationSnapshotAdmin(admin.options.OSMGeoAdmin):
                 'user',
             )
     date_hierarchy = 'date'
-    raw_id_fields = ('source', )
+    raw_id_fields = ('user', 'source', )
     list_per_page = 25
     ordering = ['-date']
     list_filter = [
@@ -62,6 +62,9 @@ class LocationSnapshotAdmin(admin.options.OSMGeoAdmin):
     ]
 
     def nearest_city(self, obj):
+        city = obj.city
+        if city:
+            return city
         nearest = obj.find_nearest_city()
         if nearest.distance != None:
             return "%s (%d mi away)" % (
